pub enum AgentError {
Failed,
AlreadyExists,
AlreadyInProgress,
NotInProgress,
ResourceNotFound,
Malformed,
WrongImplementation,
ConnectionClosed,
StunParse,
StunWrite,
CandidateParse(ParseCandidateError),
ProtocolViolation,
}Expand description
Errors that can be returned as a result of agent operations.
Variants
Failed
Failed for an unspecified reason.
AlreadyExists
The specified resource already exists and cannot be added.
AlreadyInProgress
The operation is already in progress.
NotInProgress
The operation is not in progress.
ResourceNotFound
Could not find the specified resource.
Malformed
The data provided was not in the correct format.
WrongImplementation
This data is not handled by this implementation.
ConnectionClosed
The connection to the remote has been closed.
StunParse
Parsing the STUN message failed.
StunWrite
Writing the STUN message failed.
CandidateParse(ParseCandidateError)
Parsing the candidate failed.
ProtocolViolation
Data was received that does not match the protocol specifications.