pub enum AgentPoll {
Closed,
WaitUntil(Instant),
AllocateSocket(AgentSocket),
RemoveSocket(AgentSocket),
SelectedPair(AgentSelectedPair),
ComponentStateChange(AgentComponentStateChange),
GatheredCandidate(AgentGatheredCandidate),
GatheringComplete(AgentGatheringComplete),
}Expand description
Indicates what the caller should do after calling Agent::poll
Variants
Closed
The Agent is closed. No further progress will be made.
WaitUntil(Instant)
Wait until the specified Instant has been reached (or an external event)
AllocateSocket(AgentSocket)
Connect using the specified 5-tuple. Reply (success or failure)
should be notified using StreamMut::allocated_socket with the same parameters.
RemoveSocket(AgentSocket)
It is posible to remove the specified 5-tuple. The socket will not be referenced any further.
SelectedPair(AgentSelectedPair)
A new pair has been selected for a component.
ComponentStateChange(AgentComponentStateChange)
A Component has changed state.
GatheredCandidate(AgentGatheredCandidate)
A Component has gathered a candidate.
GatheringComplete(AgentGatheringComplete)
A Component has completed gathering.